summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndrew Godwin <andrew@aeracode.org>2014-06-16 09:54:23 -0700
committerAndrew Godwin <andrew@aeracode.org>2014-06-16 09:54:43 -0700
commitf047dd2f3eb15619c9137d3389b22e6914092f1c (patch)
tree5029559609555353d9fe7c987cf41fe2f7b215f8
parentbb39037fcbe07a4c4060764533b5c03a4018bf81 (diff)
Use __first__ not __latest__ for unknown app dependencies
-rw-r--r--django/contrib/admin/migrations/0001_initial.py2
-rw-r--r--django/db/migrations/autodetector.py4
2 files changed, 3 insertions, 3 deletions
diff --git a/django/contrib/admin/migrations/0001_initial.py b/django/contrib/admin/migrations/0001_initial.py
index 988d84dc59..e7b3ebecc5 100644
--- a/django/contrib/admin/migrations/0001_initial.py
+++ b/django/contrib/admin/migrations/0001_initial.py
@@ -9,7 +9,7 @@ class Migration(migrations.Migration):
dependencies = [
migrations.swappable_dependency(settings.AUTH_USER_MODEL),
- ('contenttypes', '__latest__'),
+ ('contenttypes', '__first__'),
]
operations = [
diff --git a/django/db/migrations/autodetector.py b/django/db/migrations/autodetector.py
index 1fd28f6ad9..3b9caee8fc 100644
--- a/django/db/migrations/autodetector.py
+++ b/django/db/migrations/autodetector.py
@@ -244,10 +244,10 @@ class MigrationAutodetector(object):
if self.migrations.get(dep[0], None):
operation_dependencies.add((dep[0], self.migrations[dep[0]][-1].name))
else:
# If we can't find the other app, we add a __latest__ dependency,
# but only if we've already been through once and checked everything
if chop_mode:
- operation_dependencies.add((dep[0], "__latest__"))
+ operation_dependencies.add((dep[0], "__first__"))
else:
deps_satisfied = False
if deps_satisfied:
@@ -244,10 +244,10 @@ class MigrationAutodetector(object):
operation_dependencies.add((dep[0], self.migrations[dep[0]][-1].name))
else:
- # If we can't find the other app, we add a __latest__ dependency,
+ # If we can't find the other app, we add a __first__ dependency,
# but only if we've already been through once and checked everything
if chop_mode: